@@ -17,8 +17,7 @@
  * Authors: Benjamin Otte <otte@gnome.org>
  */
 
-#ifndef __GTK_LIST_BASE_H__
-#define __GTK_LIST_BASE_H__
+#pragma once
 
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
@@ -49,4 +48,3 @@ GType                   gtk_list_base_get_type                  (void) G_GNUC_CO
 
 G_END_DECLS
 
-#endif  /* __GTK_LIST_BASE_H__ */
