@@ -17,8 +17,7 @@
  * Authors: Benjamin Otte <otte@gnome.org>
  */
 
-#ifndef __GTK_SHORTCUT_ACTION_H__
-#define __GTK_SHORTCUT_ACTION_H__
+#pragma once
 
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
@@ -37,6 +36,8 @@ G_BEGIN_DECLS
  * @user_data: (nullable): The user data provided when activating the action
  *
  * Prototype for shortcuts based on user callbacks.
+ *
+ * Returns: %TRUE if the action was successful.
  */
 typedef gboolean (* GtkShortcutFunc) (GtkWidget *widget,
                                       GVariant  *args,
@@ -162,4 +163,3 @@ const char *            gtk_named_action_get_action_name        (GtkNamedAction
 
 G_END_DECLS
 
-#endif /* __GTK_SHORTCUT_ACTION_H__ */
